@@ -1,6 +1,6 @@
 package Tickit::Widget::Table::HeaderCell;
 {
-  $Tickit::Widget::Table::HeaderCell::VERSION = '0.002';
+  $Tickit::Widget::Table::HeaderCell::VERSION = '0.003';
 }
 use strict;
 use warnings;
@@ -12,7 +12,7 @@ Tickit::Widget::Table::HeaderCell - header cell for a table
 
 =head1 VERSION
 
-version 0.002
+version 0.003
 
 =head1 SYNOPSIS
 
@@ -34,7 +34,8 @@ sub render {
 	my $self = shift;
 	my $win = $self->window or return;
 	my $txt = $self->text;
-	my $x = $self->display_xpos;
+	# TODO should we be doing something with this?
+	# my $x = $self->display_xpos;
 	$win->goto(0,0);
 	$win->print($txt . (' ' x (-$self->table->padding + $self->cols - length $txt)), bg => 4, fg => 7, b => 1);
 }
